<?php

namespace App\Console\Commands\Debug;

use Illuminate\Console\Command;

use App\Models\Address;

class AddressCheckNode extends Command
{
	/**
	 * The name and signature of the console command.
	 *
	 * @var string
	 */
	protected $signature = 'debug:address:check:nodes'
		.' {ftn? : FTN}'
		.' {--N|node : Node Order}';

	/**
	 * The console command description.
	 *
	 * @var string
	 */
	protected $description = 'Check all addresses we use for nodes';

	/**
	 * Execute the console command.
	 *
	 * @return int
	 * @throws \Exception
	 */
	public function handle(): int
	{
		$ao = NULL;

		if ($this->argument('ftn')) {
			$ao = Address::findFTN($this->argument('ftn'));

			if (! $ao) {
				$this->error('FTN not found: ' .$this->argument('ftn'));

				return self::FAILURE;
			}

			$this->info('our address:'.our_address($ao)->ftn);
			return self::SUCCESS;
		}

		$this->table(['System','Node','Ours'],
			our_nodes($ao ? $ao->domain : NULL)
				->sortBy(fn($item)=>$this->option('node')
					? sprintf('%s:%s',$item->system->name,$item->domain->name)
					: sprintf('%s',$item->domain->name))
				->map(fn($item)=>
					[
						'System'=>$item->system->name,
						'Node'=>$item->ftn.' '.($item->echoareas->count() ? '^' : '').($item->fileareas->count() ? '*' : ''),
						'Ours'=>our_address($item)?->ftn,
					]));

		return self::SUCCESS;
	}
}